@@ -12,9 +12,11 @@ namespace Slim\Tests\Psr7;
 
 use InvalidArgumentException;
 use PHPUnit\Framework\TestCase;
-use Prophecy\PhpUnit\ProphecyTrait;
+use PHPUnit\Framework\Attributes\DataProvider;
+use PHPUnit\Framework\Attributes\Depends;
 use Psr\Http\Message\StreamInterface;
 use Psr\Http\Message\UploadedFileInterface;
+use ReflectionMethod;
 use ReflectionProperty;
 use RuntimeException;
 use Slim\Psr7\Environment;
@@ -44,8 +46,6 @@ use const UPLOAD_ERR_OK;
 
 class UploadedFileTest extends TestCase
 {
-    use ProphecyTrait;
-
     private static string $filename = './phpUxcOty';
 
     private static array $tmpFiles = ['./phpUxcOty'];
@@ -79,6 +79,15 @@ class UploadedFileTest extends TestCase
         }
     }
 
+    protected function setAccessible(ReflectionProperty|ReflectionMethod $property, bool $accessible = true): void
+    {
+        // only if PHP version < 8.1
+        if (PHP_VERSION_ID > 80100) {
+            return;
+        }
+        $property->setAccessible($accessible);
+    }
+
     protected function generateNewTmpFile(): UploadedFile
     {
         $filename = './php' . microtime();
@@ -98,6 +107,7 @@ class UploadedFileTest extends TestCase
      *
      * @dataProvider providerCreateFromGlobals
      */
+    #[DataProvider('providerCreateFromGlobals')]
     public function testCreateFromGlobalsFromFilesSuperglobal(array $input, array $expected)
     {
         $_FILES = $input;
@@ -111,7 +121,8 @@ class UploadedFileTest extends TestCase
      *
      * @dataProvider providerCreateFromGlobals
      */
-    public function testCreateFromGlobalsFromUserData(array $input)
+    #[DataProvider('providerCreateFromGlobals')]
+    public function testCreateFromGlobalsFromUserData(array $input, array $unused)
     {
         //If slim.files provided - it will return what was provided
         $userData['slim.files'] = $input;
@@ -191,6 +202,7 @@ class UploadedFileTest extends TestCase
      *
      * @return UploadedFile
      */
+    #[Depends('testConstructor')]
     public function testGetStream(UploadedFile $uploadedFile): UploadedFile
     {
         $stream = $uploadedFile->getStream();
@@ -206,6 +218,7 @@ class UploadedFileTest extends TestCase
      * @param UploadedFile $uploadedFile
      *
      */
+    #[Depends('testConstructor')]
     public function testMoveToNotWritable(UploadedFile $uploadedFile)
     {
         $this->expectException(InvalidArgumentException::class);
@@ -222,6 +235,7 @@ class UploadedFileTest extends TestCase
      *
      * @return UploadedFile
      */
+    #[Depends('testConstructor')]
     public function testMoveTo(UploadedFile $uploadedFile): UploadedFile
     {
         $tempName = uniqid('file-');
@@ -255,6 +269,7 @@ class UploadedFileTest extends TestCase
      * @param UploadedFile $uploadedFile
      *
      */
+    #[Depends('testConstructorSapi')]
     public function testMoveToSapiNonUploadedFile(UploadedFile $uploadedFile)
     {
         $this->expectException(RuntimeException::class);
@@ -270,6 +285,7 @@ class UploadedFileTest extends TestCase
      * @param UploadedFile $uploadedFile
      *
      */
+    #[Depends('testConstructorSapi')]
     public function testMoveToSapiMoveUploadedFileFails(UploadedFile $uploadedFile)
     {
         $this->expectException(RuntimeException::class);
@@ -288,6 +304,7 @@ class UploadedFileTest extends TestCase
      * @param UploadedFile $uploadedFile
      *
      */
+    #[Depends('testMoveTo')]
     public function testMoveToCannotBeDoneTwice(UploadedFile $uploadedFile)
     {
         $this->expectException(RuntimeException::class);
@@ -309,6 +326,7 @@ class UploadedFileTest extends TestCase
      * @param UploadedFile $uploadedFile
      *
      */
+    #[Depends('testConstructor')]
     public function testMoveToAgain(UploadedFile $uploadedFile)
     {
         $this->expectException(RuntimeException::class);
@@ -326,6 +344,7 @@ class UploadedFileTest extends TestCase
      * @param UploadedFile $uploadedFile
      *
      */
+    #[Depends('testConstructor')]
     public function testMovedStream(UploadedFile $uploadedFile)
     {
         $this->expectException(RuntimeException::class);
@@ -338,7 +357,7 @@ class UploadedFileTest extends TestCase
         $uploadedFile = $this->generateNewTmpFile();
 
         $fileProperty = new ReflectionProperty($uploadedFile, 'file');
-        $fileProperty->setAccessible(true);
+        $this->setAccessible($fileProperty);
         $fileName = $fileProperty->getValue($uploadedFile);
 
         $contents = file_get_contents($fileName);
@@ -416,14 +435,11 @@ class UploadedFileTest extends TestCase
     {
         $this->expectException(InvalidArgumentException::class);
 
-        $streamProphecy = $this->prophesize(StreamInterface::class);
-
-        /** @noinspection PhpUndefinedMethodInspection */
-        $streamProphecy
-            ->getMetadata('uri')
-            ->willReturn(null)
-            ->shouldBeCalled();
-        $stream = $streamProphecy->reveal();
+        $stream = $this->createMock(StreamInterface::class);
+        $stream->expects($this->once())
+            ->method('getMetadata')
+            ->with('uri')
+            ->willReturn(null);
 
         // Test with a StreamInterface that returns `null`
         // when `$stream->getMetadata('uri')` is called (which is an invalid case).
